@@ -47,7 +47,9 @@ from .Navbar import Navbar
 from .Notification import Notification
 from .NotificationsProvider import NotificationsProvider
 from .NumberInput import NumberInput
+from .Pagination import Pagination
 from .Paper import Paper
+from .PasswordInput import PasswordInput
 from .Prism import Prism
 from .Progress import Progress
 from .RadioGroup import RadioGroup
@@ -60,6 +62,7 @@ from .Skeleton import Skeleton
 from .Slider import Slider
 from .Space import Space
 from .Spoiler import Spoiler
+from .Stack import Stack
 from .Switch import Switch
 from .Tab import Tab
 from .Table import Table
@@ -124,7 +127,9 @@ __all__ = [
     "Notification",
     "NotificationsProvider",
     "NumberInput",
+    "Pagination",
     "Paper",
+    "PasswordInput",
     "Prism",
     "Progress",
     "RadioGroup",
@@ -137,6 +142,7 @@ __all__ = [
     "Slider",
     "Space",
     "Spoiler",
+    "Stack",
     "Switch",
     "Tab",
     "Table",
